@@ -16,7 +16,7 @@ class UtilsTests(TestCase):
         payload = utils.jwt_payload_handler(self.user)
 
         self.assertTrue(isinstance(payload, dict))
-        self.assertEqual(payload['user_id'], self.user.id)
+        self.assertEqual(payload['user_id'], self.user.pk)
         self.assertEqual(payload['email'], self.email)
         self.assertEqual(payload['username'], self.username)
         self.assertTrue('exp' in payload)
